/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * Copyright (c) 2012,2014 University of Zagreb
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Vedran Miletić <rivanvx@gmail.com>
 */

#include "sleep-wake-functionality.h"
#include "log.h"

NS_LOG_COMPONENT_DEFINE ("SleepWakeFunctionality");

namespace ns3 {

SleepWakeFunctionality::SleepWakeFunctionality ()
  :
    m_awake (true)
{
  NS_LOG_FUNCTION (this);
}

SleepWakeFunctionality::~SleepWakeFunctionality ()
{
  NS_LOG_FUNCTION (this);
}

void
SleepWakeFunctionality::Wake (void)
{
  NS_LOG_FUNCTION (this);
  if (!m_awake)
    {
      NS_LOG_LOGIC ("Object " << this << " was sleeping, tracing wake event and changing state");
      m_wakeTrace ();
      m_awake = true;
    }
}

void
SleepWakeFunctionality::Sleep (void)
{
  NS_LOG_FUNCTION (this);
  if (m_awake)
    {
      NS_LOG_LOGIC ("Object " << this << " was awake, tracing sleep event and changing state");
      m_sleepTrace ();
      m_awake = false;
    }
}

bool
SleepWakeFunctionality::IsAwake (void) const
{
  NS_LOG_FUNCTION (this);
  return m_awake;
}

} // namespace ns3
