/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * Copyright (c) 2012,2014 University of Zagreb
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Vedran Miletić <rivanvx@gmail.com>
 */

#include "stop-restart-functionality.h"
#include "log.h"

NS_LOG_COMPONENT_DEFINE ("StartStopFunctionality");

namespace ns3 {

StopRestartFunctionality::StopRestartFunctionality ()
  :
    m_started (true)
{
  NS_LOG_FUNCTION (this);
}

StopRestartFunctionality::~StopRestartFunctionality ()
{
  NS_LOG_FUNCTION (this);
}

void
StopRestartFunctionality::Restart (void)
{
  NS_LOG_FUNCTION (this);
  if (!m_started)
    {
      NS_LOG_LOGIC ("Object " << this << " was stopped, tracing start event and changing state");
      m_restartTrace ();
      m_started = true;
    }
}

void
StopRestartFunctionality::Stop (void)
{
  NS_LOG_FUNCTION (this);
  if (m_started)
    {
      NS_LOG_LOGIC ("Object " << this << " was started, tracing stop event and changing state");
      m_stopTrace ();
      m_started = false;
    }
}

bool
StopRestartFunctionality::IsStarted (void) const
{
  NS_LOG_FUNCTION (this);
  return m_started;
}

} // namespace ns3
