/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * Copyright (c) 2012,2015 University of Zagreb
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Vedran Miletić <rivanvx@gmail.com>
 */

#include "stoppable-and-resumable-object.h"
#include "log.h"

NS_LOG_COMPONENT_DEFINE ("StoppableAndResumableObject");

namespace ns3 {

NS_OBJECT_ENSURE_REGISTERED (StoppableAndResumableObject);

TypeId
StoppableAndResumableObject::GetTypeId (void)
{
  static TypeId tid = TypeId ("ns3::StoppableAndResumableObject")
    .SetParent<Object> ()
    .AddConstructor<StoppableAndResumableObject> ()
    .AddTraceSource ("RestartTrace",
                     "Tracing change of object state to started",
                     MakeTraceSourceAccessor (&StoppableAndResumableObject::m_restartTrace),
					 "void")
    .AddTraceSource ("StopTrace",
                     "Tracing change of object state to stopped",
                     MakeTraceSourceAccessor (&StoppableAndResumableObject::m_stopTrace),
					 "void")
    .AddTraceSource ("WakeTrace",
    			     "Tracing change of object state to awake",
		             MakeTraceSourceAccessor (&StoppableAndResumableObject::m_wakeTrace),
					 "void")
    .AddTraceSource ("SleepTrace",
	                 "Tracing change of object state to sleeping",
		             MakeTraceSourceAccessor (&StoppableAndResumableObject::m_sleepTrace),
					 "void")
  ;
  return tid;
}

StoppableAndResumableObject::StoppableAndResumableObject ()
{
  NS_LOG_FUNCTION (this);
}

StoppableAndResumableObject::~StoppableAndResumableObject ()
{
  NS_LOG_FUNCTION (this);
}

} // namespace ns3
