/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * Copyright (c) 2012,2014 University of Zagreb
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Vedran Miletić <rivanvx@gmail.com>
 */

#include "ns3/core-module.h"
#include "ns3/failure-repair-module.h"

using namespace ns3;

class ExampleStartStopObject : public Object, public StopRestartFunctionality
{
public:
  static TypeId GetTypeId (void)
  {
    static TypeId tid = TypeId ("ns3::ExampleStartStopObject")
            .SetParent<Object> ()
            .AddConstructor<ExampleStartStopObject> ()
            .AddTraceSource ("StartTrace",
                             "Tracing change of object state to started",
                             MakeTraceSourceAccessor (&ExampleStartStopObject::m_restartTrace),
							 "void")
            .AddTraceSource ("StopTrace",
                             "Tracing change of object state to stopped",
                             MakeTraceSourceAccessor (&ExampleStartStopObject::m_stopTrace),
							 "void")
            ;
    return tid;
  }

  ExampleStartStopObject ()
  {
  };
  ~ExampleStartStopObject ()
  {
  };
};

void
PrintObjectStatus (Ptr<ExampleStartStopObject> obj)
{
  NS_LOG_UNCOND (Simulator::Now () << " " << obj->IsStarted ());
}

int
main (int argc, char *argv[])
{
  LogComponentEnable ("FailureRepairModel", LogLevel (LOG_PREFIX_LEVEL | LOG_PREFIX_TIME | LOG_LEVEL_ALL));

  bool verbose = true;

  CommandLine cmd;
  cmd.AddValue ("verbose", "Tell application to log if true", verbose);

  cmd.Parse (argc, argv);

  /* ... */

  Ptr<ExampleStartStopObject> obj = CreateObject<ExampleStartStopObject> ();
  Ptr<FailureRepairModel> frm = CreateObject<FailureRepairModel> ();

  frm->SetAttribute ("NumberOfStateChanges", UintegerValue (50));
  frm->SetAttribute ("RepairedStateDuration", StringValue ("ns3::ConstantRandomVariable[Constant=1.0]"));
  frm->SetAttribute ("FailedStateDuration", StringValue ("ns3::ConstantRandomVariable[Constant=1.0]"));
  frm->AssociateObject (obj, MakeCallback (&ExampleStartStopObject::Restart, obj), MakeCallback (&ExampleStartStopObject::Stop, obj));
  
  FailureRepairTimeTrackerContainer a;
  a.Create (1);
  a.Get (0)->AssociateObject (obj, "StartTrace", "StopTrace");

  Simulator::Schedule (Seconds (1.1), &PrintObjectStatus, obj);
  Simulator::Schedule (Seconds (2.1), &PrintObjectStatus, obj);
  Simulator::Schedule (Seconds (3.1), &PrintObjectStatus, obj);
  Simulator::Schedule (Seconds (4.1), &PrintObjectStatus, obj);
  Simulator::Schedule (Seconds (5.1), &PrintObjectStatus, obj);

  Simulator::Run ();
  Simulator::Destroy ();
  
  NS_LOG_UNCOND (a.Get (0)->GetTotalTimeStarted ());
  NS_LOG_UNCOND (a.Get (0)->GetTotalTimeStopped ());
  return 0;
}
