/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * Copyright (c) 2012,2014 University of Zagreb
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Vedran Miletić <rivanvx@gmail.com>
 */

#include "failure-repair-time-tracker-container.h"

#include <ns3/failure-repair-time-tracker.h>

namespace ns3 {

FailureRepairTimeTrackerContainer::FailureRepairTimeTrackerContainer ()
{
}

FailureRepairTimeTrackerContainer::FailureRepairTimeTrackerContainer (Ptr<FailureRepairTimeTracker> fwtt)
{
  m_failedWorkingTimeTrackers.push_back (fwtt);
}

FailureRepairTimeTrackerContainer::FailureRepairTimeTrackerContainer (const FailureRepairTimeTrackerContainer &a, const FailureRepairTimeTrackerContainer &b)
{
  *this = a;
  Add (b);
}

FailureRepairTimeTrackerContainer::Iterator 
FailureRepairTimeTrackerContainer::Begin (void) const
{
  return m_failedWorkingTimeTrackers.begin ();
}

FailureRepairTimeTrackerContainer::Iterator 
FailureRepairTimeTrackerContainer::End (void) const
{
  return m_failedWorkingTimeTrackers.end ();
}

uint32_t 
FailureRepairTimeTrackerContainer::GetN (void) const
{
  return m_failedWorkingTimeTrackers.size ();
}

Ptr<FailureRepairTimeTracker> 
FailureRepairTimeTrackerContainer::Get (uint32_t i) const
{
  return m_failedWorkingTimeTrackers[i];
}

void 
FailureRepairTimeTrackerContainer::Create (uint32_t n)
{
  for (uint32_t i = 0; i < n; i++)
    {
      m_failedWorkingTimeTrackers.push_back (CreateObject<FailureRepairTimeTracker> ());
    }
}

void 
FailureRepairTimeTrackerContainer::Add (FailureRepairTimeTrackerContainer other)
{
  for (Iterator i = other.Begin (); i != other.End (); i++)
    {
      m_failedWorkingTimeTrackers.push_back (*i);
    }
}

void 
FailureRepairTimeTrackerContainer::Add (Ptr<FailureRepairTimeTracker> fwtt)
{
  m_failedWorkingTimeTrackers.push_back (fwtt);
}

} // namespace ns3
